@@ -303,7 +303,7 @@ more_widget_new (void)
         gtk_widget_set_tooltip_text (widget, _("More…"));
 
         arrow = gtk_image_new_from_icon_name ("view-more-symbolic");
-        gtk_style_context_add_class (gtk_widget_get_style_context (arrow), "dim-label");
+        gtk_widget_add_css_class (arrow, "dim-label");
         gtk_widget_set_margin_top (widget, 12);
         gtk_widget_set_margin_bottom (widget, 12);
         gtk_widget_set_hexpand (arrow, TRUE);
@@ -407,7 +407,8 @@ get_locale_infos (CcInputChooser *chooser)
         CcInputChooserPrivate *priv = cc_input_chooser_get_instance_private (chooser);
 	const gchar *type = NULL;
 	const gchar *id = NULL;
-	gchar *lang, *country;
+	g_autofree gchar *lang = NULL;
+	g_autofree gchar *country = NULL;
 	GList *list;
 
 	if (gnome_get_input_source_from_locale (priv->locale, &type, &id)) {
@@ -419,7 +420,7 @@ get_locale_infos (CcInputChooser *chooser)
 	}
 
 	if (!gnome_parse_locale (priv->locale, &lang, &country, NULL, NULL))
-		goto out;
+		return;
 
 	list = gnome_xkb_info_get_layouts_for_language (priv->xkb_info, lang);
 	add_rows_to_list (chooser, list, INPUT_SOURCE_TYPE_XKB, id);
@@ -436,10 +437,6 @@ get_locale_infos (CcInputChooser *chooser)
 	list = gnome_xkb_info_get_all_layouts (priv->xkb_info);
 	add_rows_to_list (chooser, list, INPUT_SOURCE_TYPE_XKB, id);
 	g_list_free (list);
-
-out:
-	g_free (lang);
-	g_free (country);
 }
 
 static gboolean
